Bradford Exchange Official Site: Shop for Collectibles, Jewelry and Gifts
Description: Official site of The Bradford Exchange! Shop for collectibles, NFL gifts, Thomas Kinkade merchandise, exclusive jewelry and personalized gifts for all occasions. Order today!
Keywords: the bradford exchange, bradford exchange, bradford exchange collectors plates, collector plates, collectible plates, decorative plates, bradford exchange jewelry, bradex, bradfordexchange, collectibles, wall decor art, thomas kinkade gifts, charm bracelet jewelry gifts, decorative calendars, religious collectibles

Skip to Content
The Bradford Exchange Online Homepage

0 Items in Cart
Recently Advertised
View Details Granddaughter, I Love You Music Box With Name-Engraved Charm
$59.99 US
View Details Star Wars Original Trilogy Lamp With Illuminated Lightsabers
$199.95 US
View Details A PEANUTS Christmas Tree With Lights, Motion And Music
$199.95 US
View Details Women's Anorak Supports Breast Cancer Causes
$139.00 US
View Details Disney "The Muppet Show" Wall Clock With Light And Sound
$199.95 US
View Details Strength Of Family Diamond Ring With Up To 6 Engraved Names
$119.00 US
View Details Saints For The Love Of The Game Tote Bag With Team Logos
$119.95 US
View Details "Nature's Healing Touch" Copper Beaded Bracelet
$79.00 US
View Details John Wayne On Horseback Cold-Cast Bronze Sculpture
$149.95 US
View Details The Complete American Eagle Silver Dollar Collection
$99.99 US
View Details Create Your Personalized Diamonesk Bridal Ring Set
$129.00 US
View Details United States Marine Corps Semper Fi Hooded Fleece Jacket
$129.95 US
2,320
Follow
1,249
Sign Up for E-mail Updates
Sign Up for E-mail Updates

# The Bradford Exchange Online: Home to Fine Jewelry, Unique Collectibles and Much More!

Welcome! We're delighted to have you here at The Bradford Exchange Online, where you'll find everything from exclusive, limited-edition collectibles and fine jewelry, to artistic apparel, home decor, and so much more. Join us as we celebrate the artistry of Thomas Kinkade, Lena Liu, Ted Blaylock and many other acclaimed artists. Let us feed the passions that make each collector unique, offering officially licensed collectibles and memorabilia you won't find in any store, from show stopping tributes to Elvis and magical Disney keepsakes, to exciting ways to cheer on your favorite sports teams. Looking for music boxes your daughter will treasure forever? Wishing you could give personalized gifts to all your loved ones? Cruising for that one special tribute to your favorite NASCAR® driver, searching for rare coins for Dad, or a unique train set for your best friend? You've come to the right place.

## Distinctive Treasures, Superbly Crafted

Our customers expect the very best, and it shows in each and every heirloom-quality collectible and custom-designed piece of jewelry we create. Our master artisans work with original designs and premium materials, from fine Heirloom Porcelain® to solid sterling silver, gleaming gold plating, genuine diamonds and gems, and expertly hand-painted finishes. Take our personalized birthstone jewelry, for instance. Whether you choose from our dazzling range of birthstone rings or our impressive array of birthstone pendant necklaces and bracelets, each piece will be made to your specifications, making your jewelry a true celebration of you and your loved ones.

## Our Very Best, Guaranteed

At The Bradford Exchange our reputation for excellence has always been defined by our dedication to Innovation, Artistry and Design of Enduring Value. Bring home one of our enchanting Disney Collectibles and you'll see our extreme attention to detail. Give someone special one of our breast cancer awareness figurines, and you'll understand our fierce support of a great cause. Hold one of our amazingly lifelike baby dolls in your arms and feel your heart swell. Plus, as a core element of our commitment to you, we take great pride in offering the best guarantee in the business, with returns up to one full year and free return shipping. So don't wait. A world of wonders awaits you at The Bradford Exchange Online. Shop Now!

by Collectibles Today®
0 Items in Cart
Customer Service

- Order Status
- Payment History
- Manage My Account
- Frequently Asked Questions
- Personalization Policy
- Contact Us

Company Info

- About Us
- Employment
- Privacy Policy
- Affiliates
- Site Map
- Connect With Us
- Supply Chain
- Visit Our Blog

Shop by Department

- Jewelry
- Personalized Gifts
- Apparel &
  Accessories
- Collectibles
- Home Décor

- Personalized Jewelry
- Women's Rings
- Graduation Gifts
- Sports Collectibles
- Disney Collectibles
- Shop by Theme

Shop with Confidence

FREE Return Shipping

Satisfaction Guaranteed up to 365 Days

Sign up now for E-mail Updates
Enter E-Mail Address
Enter E-Mail Address

We accept the following:

Other Sites

- The Ashton-Drake Galleries Online
- The Hamilton Collection Online
- Bradford Exchange Checks
- Artful Impressions
- International Sites

- Bradford Exchange United Kingdom
- Bradford Exchange Australia
- Bradford Exchange New Zealand